
/*
Copyright 2007-2008 Kim A. Brandt <kimabrandt@gmx.de>

This file is part of yarip.

Yarip is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Yarip is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with yarip; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

function YaripXPath(value, deep, found, notFound, whitelisted, style, dependsOnWhitelist, force)
{
	this.value = "";
	this.deep = true;
	this.force = false;
	this.dependsOnWhitelist = false;
	this.found = 0;
	this.notFound = 0;
	this.whitelisted = 0;
	this.style = null;

	this.setValue = function(value)
	{
		if (value) this.value = "" + value;
	}

	this.getValue = function()
	{
		return this.value;
	}

	this.setDeep = function(value, noStyle)
	{
		this.deep = "" + value != "false";
		if (!this.deep && !noStyle) this.style = null;
	}

	this.getDeep = function()
	{
		return this.deep;
	}

	this.setForce = function(value)
	{
		this.force = "" + value == "true";
	}

	this.getForce = function()
	{
		return this.force;
	}

	this.setDependsOnWhitelist = function(value)
	{
		this.dependsOnWhitelist = "" + value == "true";
	}

	this.getDependsOnWhitelist = function()
	{
		return this.dependsOnWhitelist;
	}

	this.setFound = function(value)
	{
		if (value) this.found = value;
	}

	this.getFound = function()
	{
		return this.found;
	}

	this.incrementFound = function()
	{
		this.found++;
	}

	this.setNotFound = function(value)
	{
		if (value) this.notFound = value;
	}

	this.getNotFound = function()
	{
		return this.notFound;
	}

	this.incrementNotFound = function()
	{
		this.notFound++;
	}

	this.setWhitelisted = function(value)
	{
		if (value) this.whitelisted = value;
	}

	this.getWhitelisted = function()
	{
		return this.whitelisted;
	}

	this.incrementWhitelisted = function()
	{
		this.whitelisted++;
	}

	this.setStyle = function(value)
	{
		if (value) this.style = value;
	}

	this.getStyle = function()
	{
		return this.style;
	}

/*	this.clone = function(purge)
	{
		var xpath = new this.constructor(this.value, this.deep, this.found, this.notFound, this.whitelisted, this.style, this.dependsOnWhitelist);
		if (purge)
		{
			xpath.found = 0;
			xpath.notFound = 0;
			xpath.whitelisted = 0;
		}
		return xpath;
	}*/

	this.clone = function(purge)
	{
		var tmp = new this.constructor(this.value, this.deep, this.found, this.notFound, this.whitelisted, this.style, this.dependsOnWhitelist);
		for (var k in this) if(this[k] && typeof(this[k]) != "object" && !k.match(/value|deep|found|notFound|whitelisted|style|dependsOnWhitelist/)) tmp[k] = this[k];
		if (purge)
		{
			tmp.found = 0;
			tmp.notFound = 0;
			tmp.whitelisted = 0;
		}
		return tmp;
	}

	this.generateXml = function()
	{
		var r = "\t\t\t<xpath value=\"" + this.value + "\"";
		if (this.deep == false) r += " deep=\"false\"";
		if (this.force == true) r += " force=\"true\"";
		if (this.dependsOnWhitelist == true) r += " dependsOnWhitelist=\"true\"";
		if (this.found > 0) r += " found=\"" + this.found + "\"";
		if (this.notFound > 0) r += " notFound=\"" + this.notFound + "\"";
		if (this.whitelisted > 0) r += " whitelisted=\"" + this.whitelisted + "\"";
		if (this.style) r += " style=\"" + this.style + "\"";
		r += "/>\n";
		return r;
	}

	this.createStyle = function(force)
	{
		if (!force && this.style) return;
		this.style = null;
		if (!this.deep || !this.value.match(/^\/?(\/([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)+$/i)) return;
		this.style = this.value.replace(/^\/+/, "").replace(/(([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)\//gi, "$1 > ").replace(/\[@/g, "\[");
	}

	this.xpathToStyle = function()
	{
		if (!this.value.match(/^\/?(\/([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)+$/i)) return null;
		return this.value.replace(/^\/+/, "").replace(/(([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)\//gi, "$1 > ").replace(/\[@/g, "\[");
	}

	this.generateCSS = function()
	{
		if (this.style) return "\t" + this.style + ",\n";
		else return "";
	}

	this.setValue(value);
	this.setDeep(deep);
	this.setFound(found);
	this.setNotFound(notFound);
	this.setWhitelisted(whitelisted);
	this.setStyle(style);
	this.setDependsOnWhitelist(dependsOnWhitelist);
	this.setForce(force);
}

function YaripItem(value)
{
	this.value = "";

	this.setValue = function(value)
	{
		if (value) this.value = "" + value;
	}

	this.getValue = function()
	{
		return this.value;
	}

	this.clone = function()
	{
		return new this.constructor(this.value);
	}

	this.generateXml = function()
	{
		return "\t\t\t<item value=\"" + this.value + "\"/>\n";
	}

	this.setValue(value);
}
